==> lnl-2.1.10.tar.gz: lnl-2.1.10/src/menu_prot.h <==
/* menu.c */
void	init_menu( void );
char	*exec_menu( menu_t *p, menu_t *dflt, char *str_goto );
bool_t	set_menu_check_item( menu_t *p );
bool_t	set_menu_radio_item( menu_t *ls, menu_t *p );
ask_t	exec_menu_ask( char *ttl, ask_t dflt, bool_t can_cancel );
char	*cb_menu_ask_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_ask_yes( menu_t **pp, menu_t **dflt );
char	*cb_menu_ask_no( menu_t **pp, menu_t **dflt );
char	*exec_menu_race( race_t *race );
char	*cb_menu_main_race( menu_t **pp, menu_t **dflt );
char	*cb_menu_sub_race( menu_t **pp, menu_t **dflt );
char	*exec_menu_sex( sex_t *sex );
char	*cb_menu_sex( menu_t **pp, menu_t **dflt );
char	*exec_menu_class( long *class_n );
char	*cb_menu_class( menu_t **pp, menu_t **dflt );
char	*exec_menu_sel_obj( trgt_kind_t *trgt_kind, pos_t pos );
char	*exec_menu_sel_mbr( mbr_t **mbr, char *ttl, bool_t flg_sel_dead );
char	*cb_menu_sel_mbr( menu_t **pp, menu_t **dflt );
char	*exec_menu_point_crsr( void );
char	*exec_menu_sel_num( long min, long max, long *p );
char	*cb_menu_main_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_exec( menu_t **pp, menu_t **dflt );
char	*cb_menu_mark( menu_t **pp, menu_t **dflt );
char	*cb_menu_sel_obj_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_sel_obj( menu_t **pp, menu_t **dflt );
char	*cb_menu_sel_obj_auto( menu_t **pp, menu_t **dflt );
bool_t	menu_switch_mark_mbr(
	trgt_kind_t trgt_kind_1, pos_t pos1,
	trgt_kind_t trgt_kind_2, pos_t pos2
);
bool_t	menu_switch_mark_mnstr(
	trgt_kind_t trgt_kind_1, pos_t pos1,
	trgt_kind_t trgt_kind_2, pos_t pos2
);
bool_t	menu_switch_mark_item(
	trgt_kind_t trgt_kind_1, pos_t pos1,
	trgt_kind_t trgt_kind_2, pos_t pos2
);
bool_t	menu_switch_mark_door(
	trgt_kind_t trgt_kind_1, pos_t pos1,
	trgt_kind_t trgt_kind_2, pos_t pos2
);
bool_t	menu_switch_mark_trap(
	trgt_kind_t trgt_kind_1, pos_t pos1,
	trgt_kind_t trgt_kind_2, pos_t pos2
);
bool_t	menu_switch_mark_square(
	trgt_kind_t trgt_kind_1, pos_t pos1,
	trgt_kind_t trgt_kind_2, pos_t pos2
);
bool_t	menu_switch_mark_pos(
	trgt_kind_t trgt_kind_1, pos_t pos1,
	trgt_kind_t trgt_kind_2, pos_t pos2
);
bool_t	menu_mark_mbr( pos_t pos1, pos_t pos2 );
bool_t	menu_mark_mnstr( pos_t pos1, pos_t pos2 );
bool_t	menu_mark_item( pos_t pos1, pos_t pos2 );
char	*cb_menu_mark_item( menu_t **pp, menu_t **dflt );
bool_t	menu_mark_door( pos_t pos1, pos_t pos2 );
char	*cb_menu_mark_door( menu_t **pp, menu_t **dflt );
bool_t	menu_mark_trap( pos_t pos1, pos_t pos2 );
char	*cb_menu_mark_trap( menu_t **pp, menu_t **dflt );
bool_t	menu_mark_square( pos_t pos1 );
bool_t	menu_mark_pos( pos_t pos1, pos_t pos2 );
bool_t	menu_mark_square_pos( pos_t pos );
void	menu_dist_mbr( void );
void	menu_dist_mnstr( void );
char	*cb_menu_dist_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_dist( menu_t **pp, menu_t **dflt );
char	*cb_menu_dist_act( menu_t **pp, menu_t **dflt );
char	*cb_menu_item( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_self_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_other( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_use( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_zap( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_smoke( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_fill_lamp( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_ready_throw( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_send( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_drop( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_srch( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_receive( menu_t **pp, menu_t **dflt );
char	*cb_menu_goto_equip( menu_t **pp, menu_t **dflt );
char	*cb_menu_equip( menu_t **pp, menu_t **dflt );
char	*cb_menu_equip_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_equip_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_equip_self( menu_t **pp, menu_t **dflt );
char	*cb_menu_equip_other( menu_t **pp, menu_t **dflt );
char	*cb_menu_equip_wear_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_equip_wear_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_equip_wear( menu_t **pp, menu_t **dflt );
char	*cb_menu_equip_take_off( menu_t **pp, menu_t **dflt );
char	*cb_menu_goto_item( menu_t **pp, menu_t **dflt );
char	*cb_menu_move( menu_t **pp, menu_t **dflt );
char	*cb_menu_fight( menu_t **pp, menu_t **dflt );
char	*cb_menu_misc( menu_t **pp, menu_t **dflt );
char	*cb_menu_stairs( menu_t **pp, menu_t **dflt );
char	*cb_menu_stairs_up( menu_t **pp, menu_t **dflt );
char	*cb_menu_stairs_down( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_exec( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_exec_all( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_cancel_all( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_sel_mbr( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_auto_off( menu_t **pp, menu_t **dflt );
char	*cb_menu_data( menu_t **pp, menu_t **dflt );
long	menu_show_mbr_data( mbr_t *mbr, long *page_n );
long	menu_edit_mbr_data( mbr_t *mbr, long *page_n );
long	menu_mbr_data(
	mbr_t *org_p, long *page_n,
	mbr_data_edit_kind_t edit_kind
);
long	exec_menu_edit_mbr_data( mbr_t *mbr, data_n_t n );
bool_t	exec_menu_ask_edit_mbr_data( mbr_t *org_p, mbr_t *mbr_p );
char	*cb_menu_mnstr_data( menu_t **pp, menu_t **dflt );
char	*cb_menu_sleep( menu_t **pp, menu_t **dflt );
char	*cb_menu_collect_gold( menu_t **pp, menu_t **dflt );
char	*cb_menu_divide_gold( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_move(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_crsr_quick_move(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_crsr_scroll_center(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_crsr_next_pos_mbr(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_crsr_next_pos_mnstr(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_crsr_next_pos_item(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_crsr_next_pos_door(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_crsr_next_pos_obj(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_crsr_next_pos_square(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_crsr_next_pos_all(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_crsr_prev_pos(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_back_log( menu_t **pp, menu_t **dflt );
char	*cb_menu_msg( menu_t **pp, menu_t **dflt );
char	*cb_menu_out_map_file( menu_t **pp, menu_t **dflt );
char	*cb_menu_shell( menu_t **pp, menu_t **dflt );
char	*cb_menu_cnf( menu_t **pp, menu_t **dflt );
char	*cb_menu_mbr_flg( menu_t **pp, menu_t **dflt );
char	*cb_menu_mbr_flg_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_fight( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_door( menu_t **pp, menu_t **dflt );
char	*cb_menu_avoid_trap( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_reload( menu_t **pp, menu_t **dflt );
char	*cb_menu_scroll_page( menu_t **pp, menu_t **dflt );
char	*cb_menu_scroll_smooth( menu_t **pp, menu_t **dflt );
char	*cb_menu_scroll_center( menu_t **pp, menu_t **dflt );
char	*cb_menu_mul_msg_line( menu_t **pp, menu_t **dflt );
char	*cb_menu_vfx( menu_t **pp, menu_t **dflt );
char	*cb_menu_vfx_wait( menu_t **pp, menu_t **dflt );
char	*cb_menu_vfx_mbr( menu_t **pp, menu_t **dflt );
char	*cb_menu_vfx_mnstr( menu_t **pp, menu_t **dflt );
char	*cb_menu_color( menu_t **pp, menu_t **dflt );
char	*cb_menu_color_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_fg_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_bg_init( menu_t **pp, menu_t **dflt );
void	menu_color_init( menu_t **pp, menu_t **dflt, int color );
char	*cb_menu_fg( menu_t **pp, menu_t **dflt );
char	*cb_menu_bg( menu_t **pp, menu_t **dflt );
char	*cb_menu_attr_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_attr( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_ptn( menu_t **pp, menu_t **dflt );
char	*cb_menu_wizard_on_light( menu_t **pp, menu_t **dflt );
char	*cb_menu_wizard_off_light( menu_t **pp, menu_t **dflt );
char	*cb_menu_about_game( menu_t **pp, menu_t **dflt );
char	*cb_menu_exit( menu_t **pp, menu_t **dflt );
bool_t	exec_menu_identify_item( mbr_t *mbr );
char	*cb_menu_identify_item( menu_t **pp, menu_t **dflt );
bool_t	exec_menu_resurrection( mbr_t *mbr );
char	*cb_menu_resurrection( menu_t **pp, menu_t **dflt );
void	sel_menu_clr( draw_menu_t *data );
menu_t	*sel_menu( menu_t *p, menu_t *dflt );
long	set_ls_menu(
	draw_menu_t *data,
	menu_t *p,
	long page_sel_n
);
menu_t	*srch_menu( menu_t *ls, char *sub_path );
menu_t	*srch_next_menu(
	menu_t *ls, menu_t *p, bool_t flg_skip_hidden
);
menu_t	*srch_goto_menu( menu_t *p, char *str_goto );
void	set_chk_on_menu( menu_t *p, char *sub_path );
void	set_chk_off_menu( menu_t *p, char *sub_path );
bool_t	set_flg_menu( menu_t *p, char *sub_path, unsigned long flg );
bool_t	clr_flg_menu( menu_t *p, char *sub_path, unsigned long flg );
bool_t	equ_flg_menu(
	menu_t *p, char *sub_path, unsigned long flg, bool_t flg_set
);
bool_t	prev_pos( void );
bool_t	next_pos_square( long d );
bool_t	next_pos_mbr( long d );
bool_t	next_pos_door( long d );
bool_t	next_pos_item( long d );
bool_t	next_pos_obj( long d );
bool_t	next_pos_item_obj( long d, bool_t flg_item );
bool_t	next_pos_item_obj_sub( long *dx, long *dy, long d, bool_t flg_item );
bool_t	next_pos_mnstr( long d );
bool_t	next_pos_mnstr_sub( long *dx, long *dy, long d );
bool_t	next_pos_all( long d );
void	wait_key( void );
void	wait_key_ex( bool_t flg_exec_key );
long	chk_key( bool_t flg_chk_menu );
void	chk_dup_accel_key( void );
void	chk_dup_accel_key_init( void );
bool_t	chk_dup_accel_key_main( menu_t *ls );
bool_t	chk_dup_accel_key_sub( unsigned char c, menu_t *ls );
bool_t	chk_accel_key( menu_t *ls, long c );
void	jump_crsr( long dx, long dy );
void	scroll_smooth( void );
void	scroll_center( void );
void	scroll_half_page( void );
void	chk_scroll( void );
void	move_crsr_mbr_trgt( mbr_t *mbr );
pos_t	*get_crsr( void );

==> lnl-2.1.20.tar.gz: lnl-2.1.20/src/menu_prot.h <==
/* menu.c */
void	init_menu( void );
void	init_ls_menu_macro( void );
char	*exec_menu( menu_t *p, menu_t *dflt, char *str_goto );
bool_t	set_menu_check_item( menu_t *p );
bool_t	set_menu_radio_item( menu_t *ls, menu_t *p );
ask_t	exec_menu_ask( char *ttl, ask_t dflt, bool_t can_cancel );
char	*cb_menu_ask_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_ask_yes( menu_t **pp, menu_t **dflt );
char	*cb_menu_ask_no( menu_t **pp, menu_t **dflt );
char	*exec_menu_race( race_t *race );
char	*cb_menu_main_race( menu_t **pp, menu_t **dflt );
char	*cb_menu_sub_race( menu_t **pp, menu_t **dflt );
char	*exec_menu_sex( sex_t *sex );
char	*cb_menu_sex( menu_t **pp, menu_t **dflt );
char	*exec_menu_class( long *class_n );
char	*cb_menu_class( menu_t **pp, menu_t **dflt );
char	*exec_menu_sel_obj( trgt_kind_t *trgt_kind, pos_t pos );
char	*exec_menu_sel_mbr( mbr_t **mbr, char *ttl, bool_t flg_sel_dead );
char	*cb_menu_sel_mbr( menu_t **pp, menu_t **dflt );
char	*exec_menu_point_crsr( void );
char	*exec_menu_sel_num( long min, long max, long *p );
char	*cb_menu_main_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_exec( menu_t **pp, menu_t **dflt );
char	*cb_menu_mark( menu_t **pp, menu_t **dflt );
char	*cb_menu_sel_obj_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_sel_obj( menu_t **pp, menu_t **dflt );
char	*cb_menu_sel_obj_auto( menu_t **pp, menu_t **dflt );
bool_t	menu_switch_mark_mbr(
	trgt_kind_t trgt_kind_1, pos_t pos1,
	trgt_kind_t trgt_kind_2, pos_t pos2
);
bool_t	menu_switch_mark_mnstr(
	trgt_kind_t trgt_kind_1, pos_t pos1,
	trgt_kind_t trgt_kind_2, pos_t pos2
);
bool_t	menu_switch_mark_item(
	trgt_kind_t trgt_kind_1, pos_t pos1,
	trgt_kind_t trgt_kind_2, pos_t pos2
);
bool_t	menu_switch_mark_door(
	trgt_kind_t trgt_kind_1, pos_t pos1,
	trgt_kind_t trgt_kind_2, pos_t pos2
);
bool_t	menu_switch_mark_trap(
	trgt_kind_t trgt_kind_1, pos_t pos1,
	trgt_kind_t trgt_kind_2, pos_t pos2
);
bool_t	menu_switch_mark_square(
	trgt_kind_t trgt_kind_1, pos_t pos1,
	trgt_kind_t trgt_kind_2, pos_t pos2
);
bool_t	menu_switch_mark_pos(
	trgt_kind_t trgt_kind_1, pos_t pos1,
	trgt_kind_t trgt_kind_2, pos_t pos2
);
bool_t	menu_mark_mbr( pos_t pos1, pos_t pos2 );
bool_t	menu_mark_mnstr( pos_t pos1, pos_t pos2 );
bool_t	menu_mark_item( pos_t pos1, pos_t pos2 );
char	*cb_menu_mark_item( menu_t **pp, menu_t **dflt );
bool_t	menu_mark_door( pos_t pos1, pos_t pos2 );
char	*cb_menu_mark_door( menu_t **pp, menu_t **dflt );
bool_t	menu_mark_trap( pos_t pos1, pos_t pos2 );
char	*cb_menu_mark_trap( menu_t **pp, menu_t **dflt );
bool_t	menu_mark_square( pos_t pos1 );
bool_t	menu_mark_pos( pos_t pos1, pos_t pos2 );
bool_t	menu_mark_square_pos( pos_t pos );
char	*menu_dist_mbr( void );
char	*menu_dist_mnstr( void );
char	*cb_menu_dist_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_dist( menu_t **pp, menu_t **dflt );
char	*cb_menu_dist_act( menu_t **pp, menu_t **dflt );
char	*cb_menu_item( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_self_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_other( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_use( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_zap( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_smoke( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_fill_lamp( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_ready_throw( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_send( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_drop( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_srch( menu_t **pp, menu_t **dflt );
char	*cb_menu_item_receive( menu_t **pp, menu_t **dflt );
char	*cb_menu_goto_equip( menu_t **pp, menu_t **dflt );
char	*cb_menu_equip( menu_t **pp, menu_t **dflt );
char	*cb_menu_equip_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_equip_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_equip_self( menu_t **pp, menu_t **dflt );
char	*cb_menu_equip_other( menu_t **pp, menu_t **dflt );
char	*cb_menu_equip_wear_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_equip_wear_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_equip_wear( menu_t **pp, menu_t **dflt );
char	*cb_menu_equip_take_off( menu_t **pp, menu_t **dflt );
char	*cb_menu_goto_item( menu_t **pp, menu_t **dflt );
char	*cb_menu_move( menu_t **pp, menu_t **dflt );
char	*cb_menu_fight( menu_t **pp, menu_t **dflt );
char	*cb_menu_misc( menu_t **pp, menu_t **dflt );
char	*cb_menu_stairs( menu_t **pp, menu_t **dflt );
char	*cb_menu_stairs_up( menu_t **pp, menu_t **dflt );
char	*cb_menu_stairs_down( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_exec( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_exec_all( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_cancel_all( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_sel_mbr( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_auto_off( menu_t **pp, menu_t **dflt );
char	*cb_menu_data( menu_t **pp, menu_t **dflt );
long	menu_show_mbr_data( mbr_t *mbr, long *page_n );
long	menu_edit_mbr_data( mbr_t *mbr, long *page_n );
long	menu_mbr_data(
	mbr_t *org_p, long *page_n,
	mbr_data_edit_kind_t edit_kind
);
long	exec_menu_edit_mbr_data( mbr_t *mbr, data_n_t n );
bool_t	exec_menu_ask_edit_mbr_data( mbr_t *org_p, mbr_t *mbr_p );
char	*cb_menu_mnstr_data( menu_t **pp, menu_t **dflt );
char	*cb_menu_gold( menu_t **pp, menu_t **dflt );
char	*cb_menu_collect_gold( menu_t **pp, menu_t **dflt );
char	*cb_menu_divide_gold( menu_t **pp, menu_t **dflt );
char	*cb_menu_formation( menu_t **pp, menu_t **dflt );
void	set_menu_formation( menu_t *ls, menu_t **dflt, long mbr_n );
char	*cb_menu_formation_sel_n( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_move(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_crsr_quick_move(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_crsr_scroll_center(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_crsr_next_pos_mbr(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_crsr_next_pos_mnstr(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_crsr_next_pos_item(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_crsr_next_pos_door(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_crsr_next_pos_obj(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_crsr_next_pos_square(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_crsr_next_pos_all(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_crsr_prev_pos(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_back_log( menu_t **pp, menu_t **dflt );
char	*cb_menu_ls_msg( menu_t **pp, menu_t **dflt );
char	*cb_menu_ls_mnstr( menu_t **pp, menu_t **dflt );
char	*cb_menu_out_map_file( menu_t **pp, menu_t **dflt );
char	*cb_menu_shell( menu_t **pp, menu_t **dflt );
char	*cb_menu_cnf( menu_t **pp, menu_t **dflt );
char	*cb_menu_mbr_flg( menu_t **pp, menu_t **dflt );
char	*cb_menu_mbr_flg_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_fight( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_door( menu_t **pp, menu_t **dflt );
char	*cb_menu_avoid_trap( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_reload( menu_t **pp, menu_t **dflt );
char	*cb_menu_scroll_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_scroll_page( menu_t **pp, menu_t **dflt );
char	*cb_menu_scroll_smooth( menu_t **pp, menu_t **dflt );
char	*cb_menu_scroll_center( menu_t **pp, menu_t **dflt );
char	*cb_menu_mul_msg_line( menu_t **pp, menu_t **dflt );
char	*cb_menu_vfx( menu_t **pp, menu_t **dflt );
char	*cb_menu_vfx_wait( menu_t **pp, menu_t **dflt );
char	*cb_menu_vfx_mbr( menu_t **pp, menu_t **dflt );
char	*cb_menu_vfx_mnstr( menu_t **pp, menu_t **dflt );
char	*cb_menu_color( menu_t **pp, menu_t **dflt );
char	*cb_menu_color_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_fg_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_bg_init( menu_t **pp, menu_t **dflt );
void	menu_color_init( menu_t **pp, menu_t **dflt, int color );
char	*cb_menu_fg( menu_t **pp, menu_t **dflt );
char	*cb_menu_bg( menu_t **pp, menu_t **dflt );
char	*cb_menu_attr_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_attr( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_ptn( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_ptn_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_macro( menu_t **pp, menu_t **dflt );
char	*cb_menu_macro_exec( menu_t **pp, menu_t **dflt );
char	*cb_menu_macro_edit( menu_t **pp, menu_t **dflt );
char	*cb_menu_wizard_on_light( menu_t **pp, menu_t **dflt );
char	*cb_menu_wizard_off_light( menu_t **pp, menu_t **dflt );
char	*cb_menu_wizard_lev_up( menu_t **pp, menu_t **dflt );
char	*cb_menu_about_game( menu_t **pp, menu_t **dflt );
char	*cb_menu_exit( menu_t **pp, menu_t **dflt );
bool_t	exec_menu_identify_item( mbr_t *mbr );
char	*cb_menu_identify_item( menu_t **pp, menu_t **dflt );
bool_t	exec_menu_resurrection( mbr_t *mbr );
char	*cb_menu_resurrection( menu_t **pp, menu_t **dflt );
void	sel_menu_clr( draw_menu_t *data );
menu_t	*sel_menu( menu_t *p, menu_t *dflt );
long	set_ls_menu(
	draw_menu_t *data,
	menu_t *p,
	long page_sel_n
);
menu_t	*srch_menu( menu_t *ls, char *sub_path );
menu_t	*srch_next_menu(
	menu_t *ls, menu_t *p, bool_t flg_skip_hidden
);
menu_t	*srch_goto_menu( menu_t *p, char *str_goto );
void	set_chk_on_menu( menu_t *p, char *sub_path );
void	set_chk_off_menu( menu_t *p, char *sub_path );
bool_t	set_flg_menu( menu_t *p, char *sub_path, unsigned long flg );
bool_t	clr_flg_menu( menu_t *p, char *sub_path, unsigned long flg );
bool_t	equ_flg_menu(
	menu_t *p, char *sub_path, unsigned long flg, bool_t flg_set
);
bool_t	prev_pos( void );
bool_t	next_pos_square( long d );
bool_t	next_pos_mbr( long d );
bool_t	next_pos_door( long d );
bool_t	next_pos_item( long d );
bool_t	next_pos_obj( long d );
bool_t	next_pos_item_obj( long d, bool_t flg_item );
bool_t	next_pos_item_obj_sub( long *dx, long *dy, long d, bool_t flg_item );
bool_t	next_pos_mnstr( long d );
bool_t	next_pos_mnstr_sub( long *dx, long *dy, long d );
bool_t	next_pos_all( long d );
void	wait_key( void );
void	wait_key_ex( bool_t flg_exec_key );
long	chk_key( bool_t flg_chk_menu );
void	chk_dup_accel_key( void );
void	chk_dup_accel_key_init( void );
bool_t	chk_dup_accel_key_main( menu_t *ls );
bool_t	chk_dup_accel_key_sub( unsigned char c, menu_t *ls );
bool_t	chk_accel_key( menu_t *ls, long c );
void	jump_crsr( long dx, long dy );
void	scroll_smooth( void );
void	scroll_center( void );
void	scroll_half_page( void );
void	chk_scroll( void );
void	move_crsr_mbr_trgt( mbr_t *mbr );
pos_t	*get_crsr( void );
